NAME

Sledge::Plugin::SNMP - Object oriented interface to SNMP

SYNOPSIS

package Foo::Pages::Bar;
use Sledge::Plugin::SNMP;

sub dispatch_baz {
    my $self = shift;
    $self->snmp->laLoad1;
    $self->snmp->addfunc( disk => '.1.3.6.1.4.1.2021.9.1.9.1' );
    $self->snmp->disk;
}

DESCRIPTION

Sledge::Plugin::SNMP provide the function which acquires a server resource by using SNMP. you can add new method or overwrite method by using the addfunc( method => MIS ).

METHODS

this plugin have the following method by the default.

ssCpuUser()
ssCpuSystem()
ssCpuIdle()
laLoad1()
laLoad2()
laLoad3()
memTotalSwap()
memAvailSwap()
memTotalReal()
memAvailReal()
memTotalFree()
memShared()
memBuffer()
memCached()
addfunc( method = MIS )

you must write config in Config/_common.pm, like this.

$C{SNMP} = { -hostname => 'localhost', -community => 'public', -port => 161 };

AUTHOR

TSUNODA Kazuya <drk@drk7.jp>

SEE ALSO

Net::SNMP